@@ -1,5 +1,5 @@
 package XML::Grammar::FictionBase::TagsTree2XML;
-$XML::Grammar::FictionBase::TagsTree2XML::VERSION = '0.20.1';
+$XML::Grammar::FictionBase::TagsTree2XML::VERSION = '0.20.2';
 use strict;
 use warnings;
 
@@ -197,6 +197,10 @@ sub _output_tag_with_childs
         {
             %$args,
             'in' => sub {
+                if ( not $args->{elem} )
+                {
+                    die "args elem";
+                }
                 return $self->_write_elem_childs( $args->{elem} );
             },
         }
@@ -207,6 +211,21 @@ sub _write_elem_childs
 {
     my ( $self, $elem ) = @_;
 
+    if ( not ref $elem )
+    {
+        return;
+
+        die "elem=[$elem]";
+    }
+    if ( ref($elem) eq 'ARRAY' )
+    {
+        # body...
+        foreach my $child (@$elem)
+        {
+            $self->_write_elem( { elem => $child, }, );
+        }
+        return;
+    }
     foreach my $child ( @{ $elem->_get_childs() } )
     {
         $self->_write_elem( { elem => $child, }, );
@@ -435,7 +454,7 @@ Internal - (to settle pod-coverage.).
 
 =head1 VERSION
 
-version 0.20.1
+version 0.20.2
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
