@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::FromProto;
-$XML::Grammar::Screenplay::FromProto::VERSION = '0.20.1';
+$XML::Grammar::Screenplay::FromProto::VERSION = '0.20.2';
 use strict;
 use warnings;
 use autodie;
@@ -79,21 +79,14 @@ sub _handle_elem_of_name_code_blk
                             $good->( "alt",      qr#.#ms ),
                         ],
                         in => sub {
-                            my $ret =
+                            my $inner_text =
                                 $elem->_get_childs()->[0]->_get_childs()->[0]
-                                ->children->contents()->[0];
+                                ->_get_childs()->[0];
 
-                            # $DB::single = 1;
-                            die if ( ref($ret) ne "" );
-                            my @lines = split /^/ms, $ret;
-                            while ( @lines and $lines[0] =~ /\A\r?\n\z/ms )
-                            {
-                                shift @lines;
-                            }
-                            while ( @lines and $lines[-1] =~ /\A\r?\n\z/ms )
-                            {
-                                pop @lines;
-                            }
+                            die if ( ref($inner_text) ne "" );
+                            $inner_text =~ s/\A(?:\r?\n)*//ms;
+                            $inner_text =~ s/(?:^\r?\n)*\z//ms;
+                            my @lines = split /^/ms, $inner_text;
                         LINES:
                             foreach my $l (@lines)
                             {
@@ -121,19 +114,37 @@ sub _handle_elem_of_name_img
 {
     my ( $self, $elem ) = @_;
 
-    $self->_output_tag_with_childs(
-        {
-            start => [
-                "image",
-                "url"   => $elem->lookup_attr("src"),
-                "alt"   => $elem->lookup_attr("alt"),
-                "title" => $elem->lookup_attr("title"),
-            ],
-            elem => $elem,
-        }
+    my $image = sub {
+        return $self->_output_tag_with_childs(
+            {
+                start => [
+                    "image",
+                    "url"   => $elem->lookup_attr("src"),
+                    "alt"   => $elem->lookup_attr("alt"),
+                    "title" => $elem->lookup_attr("title"),
+                ],
+                elem => $elem,
+            }
+        );
+    };
+
+    return (
+        ( $self->_writer->ancestor(0) eq $self->_paragraph_tag )
+        ? $image->()
+        : (
+            sub {
+                return $self->_output_tag(
+                    {
+                        start => [ "para", ],
+                        in    => $image,
+
+                        # elem  => [ scalar( $image->() ) ],
+                    }
+                );
+            }
+        )->()
     );
 
-    return;
 }
 
 sub _handle_elem_of_name_a
@@ -250,7 +261,7 @@ Converts the file $path_to_file to XML and returns it.
 
 =head1 VERSION
 
-version 0.20.1
+version 0.20.2
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
