@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::FromProto::Parser::QnD;
-$XML::Grammar::Screenplay::FromProto::Parser::QnD::VERSION = '0.20.1';
+$XML::Grammar::Screenplay::FromProto::Parser::QnD::VERSION = '0.20.2';
 use strict;
 use warnings;
 
@@ -232,7 +232,7 @@ sub _is_there_a_speech_unit
 
     return (   $self->at_line_start()
             && ( !$self->_top_is_desc() )
-            && ( $$l =~ m{\A[^\[<][^:]*:} ) );
+            && ( $$l =~ m{\A[^\[][^:]*:} ) );
 }
 
 around '_parse_non_tag_text_unit' => sub {
@@ -610,7 +610,7 @@ B<For internal use only>.
 
 =head1 VERSION
 
-version 0.20.1
+version 0.20.2
 
 =head1 METHODS
 
